{% spaceless %}
<figure class="op-interactive">
  <iframe>
    {{ blockquote|safe }}
    <script async="" src="//platform.twitter.com/widgets.js" charset="utf-8"></script>
  </iframe>
</figure>
{% endspaceless %}
