{% spaceless %}
<figure class="op-interactive">
  <iframe width="560" height="315" src="https://www.youtube.com/embed/{{video_id}}" frameborder="0" allowfullscreen></iframe>
</figure>
{% endspaceless %}
