<bulbs-carousel class="video-carousel-carousel series-carousel">
  <header class="video-carousel-header">
    <h2>Episodes</h2>
    <bulbs-carousel-previous
        class="video-carousel-previous"
        data-track-action="Single Series: Carousel Prev"
        data-track-label="#">
    </bulbs-carousel-previous>
    <bulbs-carousel-next
        class="video-carousel-next"
        data-track-action="Single Series: Carousel Next"
        data-track-label="#">
    </bulbs-carousel-next>
  </header>

  <bulbs-carousel-slider>
  </bulbs-carousel-slider>
</bulbs-carousel>
